@@ -225,7 +225,6 @@ class Client(Methods):
         self.name = name
         self.api_id = int(api_id) if api_id else None
         self.api_hash = api_hash
-        self.end_client = self.endclient(end_client)
         self.app_version = app_version
         self.device_model = device_model
         self.system_version = system_version
@@ -256,7 +255,15 @@ class Client(Methods):
             self.storage = MemoryStorage(self.name)
         else:
             self.storage = FileStorage(self.name, self.workdir)
-        
+
+        if self.end_client:
+            if self.bot_token:
+                pass
+            else:
+                self.end_client = asyncio.create_task(self.endclient(end_client))
+        else:
+            pass
+
         self.dispatcher = Dispatcher(self)
 
         self.rnd_id = MsgId
